@@ -33,8 +33,10 @@ class ConnectToS3(BaseObject):
         Updated:
             13-Jan-2023
             craigtrim@gmail.com
-            *   resource vs client
+            *   add resource and client functions (deprecate process(...))
                 https://github.com/craigtrim/awsfile-helper/issues/6
+            *   add rekognition and textract functions
+                https://github.com/craigtrim/awsfile-helper/issues/7
 
         Args:
             aws_access_key (str, Optional): Encrypted AWS Access Key
@@ -64,3 +66,13 @@ class ConnectToS3(BaseObject):
                     aws_secret_access_key=self._creds.secret_key())
 
         return s3
+
+    def rekognition(self) -> ServiceResource:
+        return client('rekognition',
+                      aws_access_key_id=self._creds.access_key(),
+                      aws_secret_access_key=self._creds.secret_key())
+
+    def textract(self) -> ServiceResource:
+        return client('textract',
+                      aws_access_key_id=self._creds.access_key(),
+                      aws_secret_access_key=self._creds.secret_key())
